@@ -25,6 +25,7 @@ from __future__ import unicode_literals
 import argparse
 import json
 import logging
+import os
 import shutil
 import sys
 
@@ -228,11 +229,7 @@ def main():
         default=None,
         help="Format of the exported file (GPGK, CSV)",
     )
-    parser_dump.add_argument(
-        "--variant_master",
-        type=str,
-        help="Master ID (Windpark ID)",
-    )
+
     parser_dump.add_argument(
         "--project",
         type=str,
@@ -398,12 +395,7 @@ def main():
 
     elif subcommands == "save":
         if args.outpath is None or args.outpath == "":
-            args.outpath = promptutil.prompt("Output Path", required=True)
-
-        if args.variant_master is None or args.variant_master == "":
-            args.variant_master = promptutil.prompt(
-                "Variant Master Name", required=True
-            )
+            args.outpath = os.getcwd()
 
         if args.project is None or args.project == "":
             args.project = promptutil.prompt("Project", required=True)
@@ -411,6 +403,12 @@ def main():
         if args.url is None or args.url == "":
             args.url = promptutil.prompt("Url", required=True)
 
+        if args.variants is None or args.variants == "":
+            args.variants = None
+
+        if args.objectclasses == "":
+            args.objectclasses = None
+
         my_emsclidump = EmsCliDump(
             url=args.url,
             username=args.username,
@@ -420,11 +418,9 @@ def main():
 
         my_emsclidump.ems_dump(
             output_path=args.outpath,
-            variant_master_id=args.variant_master,
             extension=args.format,
             objectclasses=args.objectclasses,
             variants=args.variants,
-            output_filename="TestVariantExport",
         )
 
     logger.info("EMS_CLI completed")
